from opinions import Opinion


class UsePEP517BuildOpinion(Opinion):
    def apply_changes(self):
        tool_poe_tasks = self.project.pyproject.get_or_create_table("tool", "poe", "tasks", is_super=True)
        tool_poe_tasks["build"] = "python -m build"



from opinions import Opinion


class PoetryExplicitSourcesOpinion(Opinion):
    def apply_changes(self):
        if not self.is_poetry_project:
            return

        sources = self.project.pyproject.content.get("tool", {}).get("poetry", {}).get("source", [])

        for source in sources:
            if "secondary" in source:
                if source["secondary"]:
                    source["priority"] = "supplemental"
                del source["secondary"]

        for source in sources:
            if source["priority"] == "default":
                source["priority"] = "primary"

        if not any([x["name"].lower() == "pypi" for x in sources]) and not any(
            [x.get("priority", "primary") == "primary" for x in sources]
        ):
            sources.append({"name": "pypi", "priority": "primary"})



from opinions import Opinion


class PoetryDynamicVersionOpinion(Opinion):
    def apply_changes(self):
        if not self.is_poetry_project:
            return

        build_system = self.project.pyproject.get_or_create_table("build-system", is_super=True)
        build_system["requires"] = ["poetry-core>=1.0.0", "poetry-dynamic-versioning>=1.0.0,<2.0.0"]
        build_system["build-backend"] = "poetry_dynamic_versioning.backend"

        tool_dynamic_version = self.project.pyproject.get_or_create_table(
            "tool", "poetry-dynamic-versioning", is_super=True
        )
        tool_dynamic_version["enable"] = True

        tool_poetry = self.project.pyproject.get_or_create_table("tool", "poetry", is_super=True)
        tool_poetry["version"] = "0.0.0"
